# onthefly
Change Django Settings on Custom admin page at "RUNTIME".

# Installation

```bash
pip install django-onthefly
```

# Configuration

##### Add top of the INSTALLED_APPS

```bash
onthefly
```

# Usage
##### go to django admin panel and see Onthefly Settings on bottom of the page as Custom Views
##### Add, Delete or Change settings at runtime.


# TODOs
##### 1- Add new backends apart from Redis
##### 2- Exception fallback to prevent unstabilities while changing settings at runtime
##### 3- More if you 'd like to contribute!

# CONTRIBUTE
##### All contributions are very welcomed!


